---
title: <span class="badge object-type-scalar"></span> SwissFranc
---
# <span class="badge object-type-scalar"></span> SwissFranc

Currency: Swiss franc (CHF)

## Definition

```python
# Currency: Swiss franc (CHF)
SwissFranc: typing.Literal["currencyCHF"] = "currencyCHF"
```
